==> gatsby-theme-q3-3.0.3.tgz: package/__tests__/config.int.test.js <==
import { get } from 'lodash';
import config from '../gatsby-config';

const CANONICAL = 'gatsby-plugin-canonical-urls';
const MANIFEST = 'gatsby-plugin-manifest';
const ROBOTS = 'gatsby-plugin-robots-txt';

const ENV = {
  contentfulSpaceID: 1,
  contentfulAccessToken: 1,
};

const containsResolver = (plugins = [], name) =>
  plugins.find(
    (p) => typeof p === 'object' && p.resolve === name,
  );

const checkPlugins = (args = {}, plugin) => {
  const { plugins } = config({ ...ENV, ...args });
  const statement = expect(
    containsResolver(plugins, plugin),
  );

  return {
    has: () => statement.not.toBeUndefined(),
    hasNot: () => statement.toBeUndefined(),
  };
};

describe('gatsby-config', () => {
  describe('plugins', () => {
    it('should error without contentful access token', () => {
      process.env.URL =
        'https://development.netlify.3merge.com';
      expect(() =>
        config({
          contentfulSpaceID: '1',
        }),
      ).toThrowError();
    });

    it('should include conditional plugins', () =>
      [CANONICAL, MANIFEST].forEach((name) =>
        checkPlugins(
          {
            brandingColor: '#FFF',
            title: 'Foo',
            siteUrl: 'https://google.ca',
          },
          name,
        ).has(),
      ));

    it('should exclude conditional plugins', () =>
      [CANONICAL, MANIFEST].forEach((name) =>
        checkPlugins({}, name).hasNot(),
      ));

    it.each([
      ['https://dev.netlify.3merge.com', 'disallow'],
      ['https://3merge.com', 'allow'],
    ])('should disable indexing', (url, key) => {
      process.env.URL = url;
      const { plugins } = config({ ...ENV });
      const res = containsResolver(plugins, ROBOTS);
      const prod = get(
        res,
        'options.env.production.policy',
      )[0];
      expect(prod).toHaveProperty(key, '/');
    });
  });
});

==> gatsby-theme-q3-3.2.0.tgz: package/__tests__/config.int.test.js <==
import { get } from 'lodash';
import config from '../gatsby-config';

const CANONICAL = 'gatsby-plugin-canonical-urls';
const ROBOTS = 'gatsby-plugin-robots-txt';

const ENV = {
  contentfulSpaceID: 1,
  contentfulAccessToken: 1,
};

const containsResolver = (plugins = [], name) =>
  plugins.find(
    (p) => typeof p === 'object' && p.resolve === name,
  );

const checkPlugins = (args = {}, plugin) => {
  const { plugins } = config({ ...ENV, ...args });
  const statement = expect(
    containsResolver(plugins, plugin),
  );

  return {
    has: () => statement.not.toBeUndefined(),
    hasNot: () => statement.toBeUndefined(),
  };
};

describe('gatsby-config', () => {
  describe('plugins', () => {
    it('should include conditional plugins', () =>
      [CANONICAL].forEach((name) =>
        checkPlugins(
          {
            brandingColor: '#FFF',
            title: 'Foo',
            siteUrl: 'https://google.ca',
          },
          name,
        ).has(),
      ));

    it('should exclude conditional plugins', () =>
      [CANONICAL].forEach((name) =>
        checkPlugins({}, name).hasNot(),
      ));

    it.each([
      ['https://dev.netlify.3merge.com', 'disallow'],
      ['https://3merge.com', 'allow'],
    ])('should disable indexing', (url, key) => {
      process.env.URL = url;
      const { plugins } = config({ ...ENV });
      const res = containsResolver(plugins, ROBOTS);
      const prod = get(
        res,
        'options.env.production.policy',
      )[0];
      expect(prod).toHaveProperty(key, '/');
    });
  });
});
